<?php

/**
 * @file
 * Functions for administration/settings interface.
 */

/**
 * Configuration form for sweetcaptcha.
 */
function sweetcaptcha_settings_form() {
  global $base_root;
  if (variable_get('sweetcaptcha_configured') === 1) {
    $swr = new Sweetcaptcha(
      SWEETCAPTCHA_APP_ID,
      SWEETCAPTCHA_KEY,
      SWEETCAPTCHA_SECRET,
      SWEETCAPTCHA_PUBLIC_URL
    );
    $check = $swr->get_html();
    if (strpos($check, 'error') !== FALSE) {
      $description = '<p><strong><span class="error">' . t('SweetCaptcha is currently UNREGISTERED. Please use the form below to register.') . '</span></strong></p>';
    }
    else {
      $description = '<p><strong><span class="status ok">' . t('SweetCaptcha is REGISTERED.') . '</span></strong></p>';
    }
  }
  else {
    $description = '<p><strong><span class="error">' . t('Sweetcaptcha library is not properly configured. Please read the documentation.') . '</span></strong></p>';
  }

  $designs = array(
    "0" => t("Random"),
    "1" => t("Wedding"),
    "2" => t("Movies"),
    "3" => t("Music"),
    "4" => t("Shopping"),
    "5" => t("Fun"),
    "6" => t("Food"),
    "7" => t("Sports"),
    "8" => t("Games"),
    "9" => t("Finance"),
    "10" => t("Animals"),
  );
  $languages = array(
    "8" => t("Arabic"),
    "19" => t("Bulgarian"),
    "16" => t("Chinese"),
    "9" => t("Czech"),
    "20" => t("Danish"),
    "11" => t("Dutch"),
    "1" => t("English"),
    "2" => t("French"),
    "3" => t("German"),
    "6" => t("Hebrew"),
    "14" => t("Italian"),
    "17" => t("Korean"),
    "18" => t("Norwegian"),
    "15" => t("Polish"),
    "12" => t("Portuguese"),
    "5" => t("Romanian"),
    "4" => t("Russian"),
    "10" => t("Slovak"),
    "13" => t("Spanish"),
    "7" => t("Swedish"),
  );

  $show_login = array(
    'visible' => array(
      'input[name="sweetcaptcha_reg_reset"]' => array('checked' => TRUE),
    ),
  );
  $show_register = array(
    'visible' => array(
      'input[name="sweetcaptcha_reg_reset"]' => array('checked' => FALSE),
    ),
  );
  $form['sweetcaptcha_registration'] = array(
    '#type' => 'fieldset',
    '#title' => t('Sweetcaptcha Registration'),
    '#description' => $description,
  );
  $form['sweetcaptcha_registration']['sweetcaptcha_reg_reset'] = array(
    '#type' => 'checkbox',
    '#title' => t('Already Have an Account?'),
  );
  $form['sweetcaptcha_registration']['sweetcaptcha_reg_website'] = array(
    '#type' => 'textfield',
    '#title' => t('Website'),
    '#size' => 30,
    '#default_value' => variable_get('sweetcaptcha_reg_website', $base_root),
    '#states' => $show_register,
  );
  $form['sweetcaptcha_registration']['sweetcaptcha_reg_email'] = array(
    '#type' => 'textfield',
    '#title' => t('Email'),
    '#size' => 30,
    '#default_value' => variable_get('sweetcaptcha_reg_email'),
    '#states' => $show_register,
  );
  $form['sweetcaptcha_registration']['sweetcaptcha_reg_language'] = array(
    '#type' => 'select',
    '#title' => t('Language'),
    '#default_value' => variable_get('sweetcaptcha_reg_language', '1'),
    '#options' => $languages,
    '#states' => $show_register,
  );
  $form['sweetcaptcha_registration']['sweetcaptcha_reg_design'] = array(
    '#type' => 'select',
    '#title' => t('Design'),
    '#default_value' => variable_get('sweetcaptcha_reg_design', '0'),
    '#options' => $designs,
    '#states' => $show_register,
  );

  $form['sweetcaptcha_registration']['sweetcaptcha_reg_user_id'] = array(
    '#type' => 'textfield',
    '#default_value' => variable_get('sweetcaptcha_reg_user_id', ''),
    '#title' => t('user_id'),
    '#size' => 50,
    '#states' => $show_login,
  );
  $form['sweetcaptcha_registration']['sweetcaptcha_reg_app_id'] = array(
    '#type' => 'textfield',
    '#default_value' => variable_get('sweetcaptcha_reg_app_id', ''),
    '#title' => t('app_id'),
    '#size' => 50,
    '#states' => $show_login,
  );
  $form['sweetcaptcha_registration']['sweetcaptcha_reg_key'] = array(
    '#type' => 'textfield',
    '#default_value' => variable_get('sweetcaptcha_reg_key', ''),
    '#title' => t('key'),
    '#size' => 50,
    '#states' => $show_login,
  );
  $form['sweetcaptcha_registration']['sweetcaptcha_reg_secret'] = array(
    '#type' => 'textfield',
    '#default_value' => variable_get('sweetcaptcha_reg_secret', ''),
    '#title' => t('secret'),
    '#size' => 50,
    '#states' => $show_login,
  );
  $form['actions'] = array('#type' => 'actions');
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save configuration'),
  );

  $form = system_settings_form($form);
  $form['#submit'][] = 'sweetcaptcha_settings_form_submit';
  $form['submit']['#validate'][] = 'sweetcaptcha_settings_form_validate';
  return $form;
}

/**
 * Validate function for sweetcaptcha configuration form.
 */
function sweetcaptcha_settings_form_validate($form, &$form_state) {
  if (valid_email_address($form_state['values']['sweetcaptcha_reg_email']) == FALSE) {
    form_set_error('sweetcaptcha_reg_email', t('Email, if entered, must be in valid format'));
  }
  if (valid_url($form_state['values']['sweetcaptcha_reg_website']) == FALSE) {
    form_set_error('sweetcaptcha_reg_website', t('Url, if entered, must be in valid format'));
  }
}

/**
 * Submit function for sweetcaptcha configuration form.
 */
function sweetcaptcha_settings_form_submit($form, &$form_state) {
  if (variable_get('sweetcaptcha_configured') === 1 && strpos($form['sweetcaptcha_registration']['#description'], 'status ok') == FALSE && $form_state['values']['sweetcaptcha_reg_reset'] == 0) {
    $infos = array(
      'method' => 'get_register_form',
      'platform' => 'drupal',
      'website' => $form_state['values']['sweetcaptcha_reg_website'],
      'email' => $form_state['values']['sweetcaptcha_reg_email'],
      'language' => $form_state['values']['sweetcaptcha_reg_language'],
      'theme' => $form_state['values']['sweetcaptcha_reg_design'],
      'method' => 'submit_register_form',
      'appid' => '',
      'key' => '',
      'path' => SWEETCAPTCHA_PUBLIC_URL,
      'user_ip' => ip_address(),
      'user_agent' => $_SERVER['HTTP_USER_AGENT'],
    );

    $swreg = new Sweetcaptcha(
      SWEETCAPTCHA_APP_ID,
      SWEETCAPTCHA_KEY,
      SWEETCAPTCHA_SECRET,
      SWEETCAPTCHA_PUBLIC_URL
    );

    $api_call_result = json_decode($swreg->submit_register_form($infos), TRUE);
    if (isset($api_call_result['error'])) {
      drupal_set_message($api_call_result['error'], 'error', FALSE);
    }
    else {
      variable_set('sweetcaptcha_reg_user_id', $api_call_result['user_id']);
      variable_set('sweetcaptcha_reg_app_id', $api_call_result['app_id']);
      variable_set('sweetcaptcha_reg_key', $api_call_result['key']);
      variable_set('sweetcaptcha_reg_secret', $api_call_result['secret']);
      variable_set('sweetcaptcha_reg_emailed', $api_call_result['emailed']);
    }
  }
}
